@@ -35,8 +35,7 @@
  * Banners have a title, set with [property@Banner:title]. Titles can be marked
  * up with Pango markup, use [property@Banner:use-markup] to enable it.
  *
- * The title will be shown centered or left-aligned depending on available
- * space.
+ * Title can be shown centered or left-aligned depending on available space.
  *
  * Banners can optionally have a button with text on it, set through
  * [property@Banner:button-label]. The button can be used with a `GAction`,
@@ -203,15 +202,15 @@ measure_content (GtkWidget       *widget,
 
     if (button_shown) {
       if (for_size >= 0) {
-        int button_width_nat;
+        int button_width_min;
 
         gtk_widget_measure (GTK_WIDGET (self->button), GTK_ORIENTATION_HORIZONTAL, -1,
-                            NULL, &button_width_nat, NULL, NULL);
+                            &button_width_min, NULL, NULL, NULL);
 
-        button_width_nat = MAX (button_width_nat, BUTTON_HORZ_MIN_WIDTH);
+        button_width_min = MAX (button_width_min, BUTTON_HORZ_MIN_WIDTH);
 
         /* Does button besides label + spacing + padding on the left fit? */
-        if (HORZ_PADDING + label_width_nat + HORZ_SPACING + button_width_nat > for_size) {
+        if (HORZ_PADDING + label_width_nat + HORZ_SPACING + button_width_min > for_size) {
           /* Button below label, with spacing and padding above and below */
           min = VERT_PADDING * 2 + label_min_padded + VERT_SPACING + button_min;
           nat = VERT_PADDING * 2 + label_nat_padded + VERT_SPACING + button_nat;
@@ -283,7 +282,7 @@ allocate_content (GtkWidget *widget,
                       NULL, &label_width, NULL, NULL);
   gtk_widget_measure (GTK_WIDGET (self->button),
                       GTK_ORIENTATION_HORIZONTAL, -1,
-                      NULL, &button_width, NULL, NULL);
+                      &button_width, NULL, NULL, NULL);
   gtk_widget_measure (GTK_WIDGET (self->title),
                       GTK_ORIENTATION_VERTICAL, width,
                       NULL, &label_height, NULL, NULL);
@@ -351,7 +350,7 @@ adw_banner_class_init (AdwBannerClass *klass)
   object_class->dispose = adw_banner_dispose;
 
   /**
-   * AdwBanner:title:
+   * AdwBanner:title: (attributes org.gtk.Property.get=adw_banner_get_title org.gtk.Property.set=adw_banner_set_title)
    *
    * The title for this banner.
    *
@@ -365,7 +364,7 @@ adw_banner_class_init (AdwBannerClass *klass)
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwBanner:button-label:
+   * AdwBanner:button-label: (attributes org.gtk.Property.get=adw_banner_get_button_label org.gtk.Property.set=adw_banner_set_button_label)
    *
    * The label to show on the button.
    *
@@ -382,7 +381,7 @@ adw_banner_class_init (AdwBannerClass *klass)
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwBanner:use-markup:
+   * AdwBanner:use-markup: (attributes org.gtk.Property.get=adw_banner_get_use_markup org.gtk.Property.set=adw_banner_set_use_markup)
    *
    * Whether to use Pango markup for the banner title.
    *
@@ -396,7 +395,7 @@ adw_banner_class_init (AdwBannerClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwBanner:revealed:
+   * AdwBanner:revealed: (attributes org.gtk.Property.get=adw_banner_get_revealed org.gtk.Property.set=adw_banner_set_revealed)
    *
    * Whether the banner is currently revealed.
    *
@@ -525,7 +524,7 @@ adw_banner_new (const char *title)
 }
 
 /**
- * adw_banner_get_title:
+ * adw_banner_get_title: (attributes org.gtk.Method.get_property=title)
  * @self: a banner
  *
  * Gets the title for @self.
@@ -543,7 +542,7 @@ adw_banner_get_title (AdwBanner *self)
 }
 
 /**
- * adw_banner_set_title:
+ * adw_banner_set_title: (attributes org.gtk.Method.set_property=title)
  * @self: a banner
  * @title: the title
  *
@@ -569,7 +568,7 @@ adw_banner_set_title (AdwBanner  *self,
 }
 
 /**
- * adw_banner_get_button_label:
+ * adw_banner_get_button_label: (attributes org.gtk.Method.get_property=button-label)
  * @self: a banner
  *
  * Gets the button label for @self.
@@ -587,7 +586,7 @@ adw_banner_get_button_label (AdwBanner *self)
 }
 
 /**
- * adw_banner_set_button_label:
+ * adw_banner_set_button_label: (attributes org.gtk.Method.set_property=button-label)
  * @self: a banner
  * @label: (nullable): the label
  *
@@ -617,7 +616,7 @@ adw_banner_set_button_label (AdwBanner  *self,
 }
 
 /**
- * adw_banner_get_use_markup:
+ * adw_banner_get_use_markup: (attributes org.gtk.Method.get_property=use-markup)
  * @self: a banner
  *
  * Gets whether to use Pango markup for the banner title.
@@ -635,7 +634,7 @@ adw_banner_get_use_markup (AdwBanner *self)
 }
 
 /**
- * adw_banner_set_use_markup:
+ * adw_banner_set_use_markup: (attributes org.gtk.Method.set_property=use-markup)
  * @self: a banner
  * @use_markup: whether to use markup
  *
@@ -662,7 +661,7 @@ adw_banner_set_use_markup (AdwBanner *self,
 }
 
 /**
- * adw_banner_get_revealed:
+ * adw_banner_get_revealed: (attributes org.gtk.Method.get_property=revealed)
  * @self: a banner
  *
  * Gets if a banner is revealed
@@ -680,7 +679,7 @@ adw_banner_get_revealed (AdwBanner *self)
 }
 
 /**
- * adw_banner_set_revealed:
+ * adw_banner_set_revealed: (attributes org.gtk.Method.get_property=revealed)
  * @self: a banner
  * @revealed: whether a banner should be revealed
  *
