@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Alice Mikhaylenko <alicem@gnome.org>
+ * Copyright (C) 2020 Alexander Mikhaylenko <alexm@gnome.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -26,7 +26,7 @@
  * A lines indicator for [class@Carousel].
  *
  * <picture>
- *   <source srcset="carousel-indicator-lines-dark.png" media="(prefers-color-scheme: dark)">
+ *   <source srcset="carousel-indicator-dots-lines.png" media="(prefers-color-scheme: dark)">
  *   <img src="carousel-indicator-lines.png" alt="carousel-indicator-lines">
  * </picture>
  *
@@ -317,7 +317,7 @@ adw_carousel_indicator_lines_class_init (AdwCarouselIndicatorLinesClass *klass)
   widget_class->snapshot = adw_carousel_indicator_lines_snapshot;
 
   /**
-   * AdwCarouselIndicatorLines:carousel:
+   * AdwCarouselIndicatorLines:carousel: (attributes org.gtk.Property.get=adw_carousel_indicator_lines_get_carousel org.gtk.Property.set=adw_carousel_indicator_lines_set_carousel)
    *
    * The displayed carousel.
    */
@@ -344,8 +344,6 @@ adw_carousel_indicator_lines_init (AdwCarouselIndicatorLines *self)
 
   self->animation =
     adw_timed_animation_new (GTK_WIDGET (self), 0, 1, 0, target);
-
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (self->animation), ADW_LINEAR);
 }
 
 /**
@@ -362,7 +360,7 @@ adw_carousel_indicator_lines_new (void)
 }
 
 /**
- * adw_carousel_indicator_lines_get_carousel:
+ * adw_carousel_indicator_lines_get_carousel: (attributes org.gtk.Method.get_property=carousel)
  * @self: an indicator
  *
  * Gets the displayed carousel.
@@ -378,7 +376,7 @@ adw_carousel_indicator_lines_get_carousel (AdwCarouselIndicatorLines *self)
 }
 
 /**
- * adw_carousel_indicator_lines_set_carousel:
+ * adw_carousel_indicator_lines_set_carousel: (attributes org.gtk.Method.set_property=carousel)
  * @self: an indicator
  * @carousel: (nullable): a carousel
  *
