@@ -71,7 +71,6 @@ typedef struct
   GtkWidget *indicator;
   GtkBox *suffixes;
   GtkBox *prefixes;
-  GSignalGroup *buffer_signals;
 
   gboolean empty;
   double empty_progress;
@@ -85,11 +84,13 @@ typedef struct
 } AdwEntryRowPrivate;
 
 static void adw_entry_row_buildable_init (GtkBuildableIface *iface);
+static void adw_entry_row_accessible_init (GtkAccessibleInterface *iface);
 static void adw_entry_row_editable_init (GtkEditableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (AdwEntryRow, adw_entry_row, ADW_TYPE_PREFERENCES_ROW,
                          G_ADD_PRIVATE (AdwEntryRow)
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, adw_entry_row_buildable_init)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ACCESSIBLE, adw_entry_row_accessible_init)
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_EDITABLE, adw_entry_row_editable_init))
 
 static GtkBuildableIface *parent_buildable_iface;
@@ -102,8 +103,6 @@ enum {
   PROP_ATTRIBUTES,
   PROP_ENABLE_EMOJI_COMPLETION,
   PROP_ACTIVATES_DEFAULT,
-  PROP_TEXT_LENGTH,
-  PROP_MAX_LENGTH,
   PROP_LAST_PROP,
 };
 
@@ -150,10 +149,10 @@ update_empty (AdwEntryRow *self)
   gboolean editable = gtk_editable_get_editable (GTK_EDITABLE (priv->text));
   gboolean empty = gtk_entry_buffer_get_length (buffer) == 0;
 
-  gtk_widget_set_child_visible (priv->edit_icon, !priv->text_changed && (!priv->editing || !editable));
+  gtk_widget_set_visible (priv->edit_icon, !priv->text_changed && (!priv->editing || !editable));
   gtk_widget_set_sensitive (priv->edit_icon, editable);
-  gtk_widget_set_child_visible (priv->indicator, priv->editing && priv->show_indicator);
-  gtk_widget_set_child_visible (priv->apply_button, priv->text_changed);
+  gtk_widget_set_visible (priv->indicator, priv->editing && priv->show_indicator);
+  gtk_widget_set_visible (priv->apply_button, priv->text_changed);
 
   priv->empty = empty && !(focused && editable) && !priv->text_changed;
 
@@ -248,33 +247,16 @@ text_activated_cb (AdwEntryRow *self)
 {
   AdwEntryRowPrivate *priv = adw_entry_row_get_instance_private (self);
 
-  if (gtk_widget_get_child_visible (priv->apply_button)) {
+  if (gtk_widget_get_visible (priv->apply_button)) {
     apply_button_clicked_cb (self);
   } else {
-    const char *action_name;
-
     if (priv->activates_default)
       gtk_widget_activate_default (GTK_WIDGET (self));
 
     g_signal_emit (self, signals[SIGNAL_ENTRY_ACTIVATED], 0);
-
-    action_name = gtk_actionable_get_action_name (GTK_ACTIONABLE (self));
-
-    if (action_name) {
-      GVariant *target = gtk_actionable_get_action_target_value (GTK_ACTIONABLE (self));
-
-      gtk_widget_activate_action_variant (GTK_WIDGET (self), action_name, target);
-    }
   }
 }
 
-static void
-on_length_changed (AdwEntryRow    *self,
-                   GtkEntryBuffer *buffer)
-{
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TEXT_LENGTH]);
-}
-
 static void
 measure_editable_area (GtkWidget      *widget,
                        GtkOrientation  orientation,
@@ -289,10 +271,6 @@ measure_editable_area (GtkWidget      *widget,
   int text_min = 0, text_nat = 0;
   int title_min = 0, title_nat = 0;
   int empty_min = 0, empty_nat = 0;
-  int indicator_min = 0, indicator_nat = 0;
-  int edit_icon_min = 0, edit_icon_nat = 0;
-  int apply_btn_min = 0, apply_btn_nat = 0;
-  int icon_min = 0, icon_nat = 0;
 
   gtk_widget_measure (priv->text, orientation, for_size,
                       &text_min, &text_nat, NULL, NULL);
@@ -301,27 +279,11 @@ measure_editable_area (GtkWidget      *widget,
   gtk_widget_measure (priv->empty_title, orientation, for_size,
                       &empty_min, &empty_nat, NULL, NULL);
 
-  gtk_widget_measure (priv->indicator, orientation, for_size,
-                      &indicator_min, &indicator_nat, NULL, NULL);
-  gtk_widget_measure (priv->edit_icon, orientation, for_size,
-                      &edit_icon_min, &edit_icon_nat, NULL, NULL);
-  gtk_widget_measure (priv->apply_button, orientation, for_size,
-                      &apply_btn_min, &apply_btn_nat, NULL, NULL);
+  if (minimum)
+    *minimum = MAX (text_min + TITLE_SPACING + title_min, empty_min);
 
-  icon_min = MAX (indicator_min, MAX (edit_icon_min, apply_btn_min));
-  icon_nat = MAX (indicator_nat, MAX (edit_icon_nat, apply_btn_nat));
-
-  if (orientation == GTK_ORIENTATION_HORIZONTAL) {
-    if (minimum)
-      *minimum = MAX (text_min, MAX (title_min, empty_min)) + icon_min;
-    if (natural)
-      *natural = MAX (text_nat, MAX (title_nat, empty_nat)) + icon_nat;
-  } else {
-    if (minimum)
-      *minimum = MAX (text_min + TITLE_SPACING + title_min, MAX (empty_min, icon_min));
-    if (natural)
-      *natural = MAX (text_nat + TITLE_SPACING + title_nat, MAX (empty_nat, icon_nat));
-  }
+  if (natural)
+    *natural = MAX (text_nat + TITLE_SPACING + title_nat, empty_nat);
 
   if (minimum_baseline)
     *minimum_baseline = -1;
@@ -330,26 +292,6 @@ measure_editable_area (GtkWidget      *widget,
     *natural_baseline = -1;
 }
 
-static int
-get_icon_width (AdwEntryRow *self,
-                int          width,
-                int          height)
-{
-  AdwEntryRowPrivate *priv = adw_entry_row_get_instance_private (self);
-  int indicator_width, edit_icon_width, apply_btn_width, icon_width;
-
-  gtk_widget_measure (priv->indicator, GTK_ORIENTATION_HORIZONTAL, height,
-                      NULL, &indicator_width, NULL, NULL);
-  gtk_widget_measure (priv->edit_icon, GTK_ORIENTATION_HORIZONTAL, height,
-                      NULL, &edit_icon_width, NULL, NULL);
-  gtk_widget_measure (priv->apply_button, GTK_ORIENTATION_HORIZONTAL, height,
-                      NULL, &apply_btn_width, NULL, NULL);
-
-  icon_width = MAX (indicator_width, MAX (edit_icon_width, apply_btn_width));
-
-  return MIN (icon_width, width);
-}
-
 static void
 allocate_editable_area (GtkWidget *widget,
                         int        width,
@@ -361,8 +303,6 @@ allocate_editable_area (GtkWidget *widget,
   gboolean is_rtl = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL;
   GskTransform *transform;
   int empty_height = 0, title_height = 0, text_height = 0, text_baseline = -1;
-  int icon_width;
-  gboolean has_icon;
   float empty_scale, title_scale, title_offset;
 
   gtk_widget_measure (priv->title, GTK_ORIENTATION_VERTICAL, width,
@@ -372,15 +312,6 @@ allocate_editable_area (GtkWidget *widget,
   gtk_widget_measure (priv->text, GTK_ORIENTATION_VERTICAL, width,
                       NULL, &text_height, NULL, &text_baseline);
 
-  has_icon = gtk_widget_get_child_visible (priv->edit_icon) ||
-             gtk_widget_get_child_visible (priv->indicator) ||
-             gtk_widget_get_child_visible (priv->apply_button);
-
-  if (has_icon)
-    icon_width = get_icon_width (self, width, height);
-  else
-    icon_width = 0;
-
   empty_scale = (float) adw_lerp (1.0, (double) title_height / empty_height, priv->empty_progress);
   title_scale = (float) adw_lerp ((double) empty_height / title_height, 1.0, priv->empty_progress);
   title_offset = (float) adw_lerp ((double) (height - empty_height) / 2.0,
@@ -392,34 +323,19 @@ allocate_editable_area (GtkWidget *widget,
     transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (width, 0));
   transform = gsk_transform_scale (transform, empty_scale, empty_scale);
   if (is_rtl)
-    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (icon_width - width, 0));
-  gtk_widget_allocate (priv->empty_title, width - icon_width, empty_height, -1, transform);
+    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (-width, 0));
+  gtk_widget_allocate (priv->empty_title, width, empty_height, -1, transform);
 
   transform = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (0, title_offset));
   if (is_rtl)
     transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (width, 0));
   transform = gsk_transform_scale (transform, title_scale, title_scale);
   if (is_rtl)
-    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (icon_width - width, 0));
-  gtk_widget_allocate (priv->title, width - icon_width, title_height, -1, transform);
+    transform = gsk_transform_translate (transform, &GRAPHENE_POINT_INIT (-width, 0));
+  gtk_widget_allocate (priv->title, width, title_height, -1, transform);
 
-  if (is_rtl)
-    transform = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (icon_width, 0));
-  else
-    transform = NULL;
   text_baseline += (int) ((double) (height + title_height - text_height + TITLE_SPACING) / 2.0);
-  gtk_widget_allocate (priv->text, width - icon_width, height, text_baseline, transform);
-
-  if (has_icon) {
-    if (is_rtl)
-      transform = NULL;
-    else
-      transform = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (width - icon_width, 0));
-
-    gtk_widget_allocate (priv->edit_icon, icon_width, height, -1, gsk_transform_ref (transform));
-    gtk_widget_allocate (priv->indicator, icon_width, height, -1, gsk_transform_ref (transform));
-    gtk_widget_allocate (priv->apply_button, icon_width, height, -1, transform);
-  }
+  gtk_widget_allocate (priv->text, width, height, text_baseline, NULL);
 }
 
 static gboolean
@@ -461,12 +377,6 @@ adw_entry_row_get_property (GObject     *object,
   case PROP_ACTIVATES_DEFAULT:
     g_value_set_boolean (value, adw_entry_row_get_activates_default (self));
     break;
-  case PROP_TEXT_LENGTH:
-    g_value_set_uint (value, adw_entry_row_get_text_length (self));
-    break;
-  case PROP_MAX_LENGTH:
-    g_value_set_int (value, adw_entry_row_get_max_length (self));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -510,9 +420,6 @@ adw_entry_row_set_property (GObject       *object,
   case PROP_ACTIVATES_DEFAULT:
     adw_entry_row_set_activates_default (self, g_value_get_boolean (value));
     break;
-  case PROP_MAX_LENGTH:
-    adw_entry_row_set_max_length (self, g_value_get_int (value));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -546,7 +453,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
   widget_class->grab_focus = adw_entry_row_grab_focus;
 
   /**
-   * AdwEntryRow:show-apply-button:
+   * AdwEntryRow:show-apply-button: (attributes org.gtk.Property.get=adw_entry_row_get_show_apply_button org.gtk.Property.set=adw_entry_row_set_show_apply_button)
    *
    * Whether to show the apply button.
    *
@@ -566,7 +473,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwEntryRow:input-hints:
+   * AdwEntryRow:input-hints: (attributes org.gtk.Property.get=adw_entry_row_get_input_hints org.gtk.Property.set=adw_entry_row_set_input_hints)
    *
    * Additional input hints for the entry row.
    *
@@ -583,7 +490,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwEntryRow:input-purpose:
+   * AdwEntryRow:input-purpose: (attributes org.gtk.Property.get=adw_entry_row_get_input_purpose org.gtk.Property.set=adw_entry_row_set_input_purpose)
    *
    * The input purpose of the entry row.
    *
@@ -598,7 +505,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwEntryRow:attributes:
+   * AdwEntryRow:attributes: (attributes org.gtk.Property.get=adw_entry_row_get_attributes org.gtk.Property.set=adw_entry_row_set_attributes)
    *
    * A list of Pango attributes to apply to the text of the embedded entry.
    *
@@ -613,7 +520,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwEntryRow:enable-emoji-completion:
+   * AdwEntryRow:enable-emoji-completion: (attributes org.gtk.Property.get=adw_entry_row_get_enable_emoji_completion org.gtk.Property.set=adw_entry_row_set_enable_emoji_completion)
    *
    * Whether to suggest emoji replacements on the entry row.
    *
@@ -627,7 +534,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwEntryRow:activates-default:
+   * AdwEntryRow:activates-default: (attributes org.gtk.Property.get=adw_entry_row_get_activates_default org.gtk.Property.set=adw_entry_row_set_activates_default)
    *
    * Whether activating the embedded entry can activate the default widget.
    *
@@ -638,31 +545,6 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
-  /**
-   * AdwEntryRow:text-length:
-   *
-   * The length of the text in the entry row.
-   *
-   * Since: 1.5
-   */
-  props[PROP_TEXT_LENGTH] =
-    g_param_spec_uint ("text-length", NULL, NULL,
-                       0, G_MAXUINT16, 0,
-                       G_PARAM_READABLE);
-
-  /**
-   * AdwEntryRow:max-length:
-   *
-   * Maximum number of characters for the entry.
-   *
-   * Since: 1.6
-   */
-  props[PROP_MAX_LENGTH] =
-    g_param_spec_int ("max-length", NULL, NULL,
-                      0, GTK_ENTRY_BUFFER_MAX_SIZE,
-                      0,
-                      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
   gtk_editable_install_properties (object_class, PROP_LAST_PROP);
@@ -721,7 +603,6 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, AdwEntryRow, edit_icon);
   gtk_widget_class_bind_template_child_private (widget_class, AdwEntryRow, apply_button);
   gtk_widget_class_bind_template_child_private (widget_class, AdwEntryRow, indicator);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwEntryRow, buffer_signals);
 
   gtk_widget_class_bind_template_callback (widget_class, pressed_cb);
   gtk_widget_class_bind_template_callback (widget_class, text_state_flags_changed_cb);
@@ -731,6 +612,7 @@ adw_entry_row_class_init (AdwEntryRowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, text_activated_cb);
   gtk_widget_class_bind_template_callback (widget_class, apply_button_clicked_cb);
 
+  gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_TEXT_BOX);
   g_type_ensure (ADW_TYPE_GIZMO);
 }
 
@@ -743,9 +625,6 @@ adw_entry_row_init (AdwEntryRow *self)
   gtk_widget_init_template (GTK_WIDGET (self));
   gtk_editable_init_delegate (GTK_EDITABLE (self));
 
-  gtk_widget_set_child_visible (priv->indicator, FALSE);
-  gtk_widget_set_child_visible (priv->apply_button, FALSE);
-
   adw_gizmo_set_measure_func (ADW_GIZMO (priv->editable_area), (AdwGizmoMeasureFunc) measure_editable_area);
   adw_gizmo_set_allocate_func (ADW_GIZMO (priv->editable_area), (AdwGizmoAllocateFunc) allocate_editable_area);
   adw_gizmo_set_focus_func (ADW_GIZMO (priv->editable_area), (AdwGizmoFocusFunc) adw_widget_focus_child);
@@ -762,15 +641,6 @@ adw_entry_row_init (AdwEntryRow *self)
     adw_timed_animation_new (GTK_WIDGET (self), 0, 0,
                              EMPTY_ANIMATION_DURATION, target);
 
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (priv->empty_animation), ADW_EASE);
-
-  g_signal_group_connect_swapped (priv->buffer_signals, "notify::length",
-                                  G_CALLBACK (on_length_changed), self);
-
-  g_object_bind_property (GTK_TEXT (priv->text), "buffer",
-                          priv->buffer_signals, "target",
-                          G_BINDING_SYNC_CREATE);
-
   update_empty (self);
 }
 
@@ -802,6 +672,19 @@ adw_entry_row_buildable_init (GtkBuildableIface *iface)
   iface->add_child = adw_entry_row_buildable_add_child;
 }
 
+static gboolean
+adw_entry_row_accessible_get_platform_state (GtkAccessible              *accessible,
+                                             GtkAccessiblePlatformState  state)
+{
+  return gtk_editable_delegate_get_accessible_platform_state (GTK_EDITABLE (accessible), state);
+}
+
+static void
+adw_entry_row_accessible_init (GtkAccessibleInterface *iface)
+{
+  iface->get_platform_state = adw_entry_row_accessible_get_platform_state;
+}
+
 static GtkEditable *
 adw_entry_row_get_delegate (GtkEditable *editable)
 {
@@ -849,7 +732,6 @@ adw_entry_row_add_prefix (AdwEntryRow *self,
 
   g_return_if_fail (ADW_IS_ENTRY_ROW (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   priv = adw_entry_row_get_instance_private (self);
 
@@ -874,7 +756,6 @@ adw_entry_row_add_suffix (AdwEntryRow *self,
 
   g_return_if_fail (ADW_IS_ENTRY_ROW (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   priv = adw_entry_row_get_instance_private (self);
 
@@ -915,7 +796,7 @@ adw_entry_row_remove (AdwEntryRow *self,
 }
 
 /**
- * adw_entry_row_get_show_apply_button:
+ * adw_entry_row_get_show_apply_button: (attributes org.gtk.Method.get_property=show-apply-button)
  * @self: an entry row
  *
  * Gets whether @self can show the apply button.
@@ -937,7 +818,7 @@ adw_entry_row_get_show_apply_button (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_show_apply_button:
+ * adw_entry_row_set_show_apply_button: (attributes org.gtk.Method.set_property=show-apply-button)
  * @self: an entry row
  * @show_apply_button: whether to show the apply button
  *
@@ -979,7 +860,7 @@ adw_entry_row_set_show_apply_button (AdwEntryRow *self,
 }
 
 /**
- * adw_entry_row_get_input_hints:
+ * adw_entry_row_get_input_hints: (attributes org.gtk.Method.get_property=input-hints)
  * @self: an entry row
  *
  * Gets the additional input hints of @self.
@@ -1001,7 +882,7 @@ adw_entry_row_get_input_hints (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_input_hints:
+ * adw_entry_row_set_input_hints: (attributes org.gtk.Method.set_property=input-hints)
  * @self: an entry row
  * @hints: the hints
  *
@@ -1032,7 +913,7 @@ adw_entry_row_set_input_hints (AdwEntryRow   *self,
 }
 
 /**
- * adw_entry_row_get_input_purpose:
+ * adw_entry_row_get_input_purpose: (attributes org.gtk.Method.get_property=input-purpose)
  * @self: an entry row
  *
  * Gets the input purpose of @self.
@@ -1054,7 +935,7 @@ adw_entry_row_get_input_purpose (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_input_purpose:
+ * adw_entry_row_set_input_purpose: (attributes org.gtk.Method.set_property=input-purpose)
  * @self: an entry row
  * @purpose: the purpose
  *
@@ -1083,7 +964,7 @@ adw_entry_row_set_input_purpose (AdwEntryRow     *self,
 }
 
 /**
- * adw_entry_row_get_attributes:
+ * adw_entry_row_get_attributes: (attributes org.gtk.Method.get_property=attributes)
  * @self: an entry row
  *
  * Gets Pango attributes applied to the text of the embedded entry.
@@ -1105,7 +986,7 @@ adw_entry_row_get_attributes (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_attributes:
+ * adw_entry_row_set_attributes: (attributes org.gtk.Method.set_property=attributes)
  * @self: an entry row
  * @attributes: (nullable): a list of attributes
  *
@@ -1135,7 +1016,7 @@ adw_entry_row_set_attributes (AdwEntryRow   *self,
 }
 
 /**
- * adw_entry_row_get_enable_emoji_completion:
+ * adw_entry_row_get_enable_emoji_completion: (attributes org.gtk.Method.get_property=enable-emoji-completion)
  * @self: an entry row
  *
  * Gets whether to suggest emoji replacements on @self.
@@ -1157,7 +1038,7 @@ adw_entry_row_get_enable_emoji_completion (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_enable_emoji_completion:
+ * adw_entry_row_set_enable_emoji_completion: (attributes org.gtk.Method.get_property=enable-emoji-completion)
  * @self: an entry row
  * @enable_emoji_completion: Whether emoji completion should be enabled or not
  *
@@ -1188,7 +1069,7 @@ adw_entry_row_set_enable_emoji_completion (AdwEntryRow *self,
 }
 
 /**
- * adw_entry_row_get_activates_default:
+ * adw_entry_row_get_activates_default: (attributes org.gtk.Method.get_property=activates-default)
  * @self: an entry row
  *
  * Gets whether activating the embedded entry can activate the default widget.
@@ -1210,7 +1091,7 @@ adw_entry_row_get_activates_default (AdwEntryRow *self)
 }
 
 /**
- * adw_entry_row_set_activates_default:
+ * adw_entry_row_set_activates_default: (attributes org.gtk.Method.set_property=activates-default)
  * @self: an entry row
  * @activates: whether to activate the default widget
  *
@@ -1279,75 +1160,6 @@ adw_entry_row_set_show_indicator (AdwEntryRow *self,
   update_empty (self);
 }
 
-/**
- * adw_entry_row_get_text_length:
- * @self: an entry row
- *
- * Retrieves the current length of the text in @self.
- *
- * Returns: The current number of characters in @self, or 0 if there are none.
- *
- * Since: 1.5
- */
-guint
-adw_entry_row_get_text_length (AdwEntryRow *self)
-{
-  AdwEntryRowPrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_ENTRY_ROW (self), 0);
-
-  priv = adw_entry_row_get_instance_private (self);
-
-  return gtk_text_get_text_length (GTK_TEXT (priv->text));
-}
-
-/**
- * adw_entry_row_set_max_length:
- * @self: an entry row
- * @max_length: maximum length of the entry
- *
- * Sets the maximum length of the entry.
- *
- * Since: 1.6
- */
-void
-adw_entry_row_set_max_length (AdwEntryRow *self,
-                              int          max_length)
-{
-  AdwEntryRowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_ENTRY_ROW (self));
-
-  priv = adw_entry_row_get_instance_private (self);
-
-  if (adw_entry_row_get_max_length (self) == max_length)
-    return;
-
-  gtk_text_set_max_length (GTK_TEXT (priv->text), max_length);
-}
-
-/**
- * adw_entry_row_get_max_length:
- * @self: an entry row
- *
- * Retrieves the maximum length of the entry.
- *
- * Returns: The maximum length of the entry.
- *
- * Since: 1.6
- */
-int
-adw_entry_row_get_max_length (AdwEntryRow *self)
-{
-  AdwEntryRowPrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_ENTRY_ROW (self), 0);
-
-  priv = adw_entry_row_get_instance_private (self);
-
-  return gtk_text_get_max_length (GTK_TEXT (priv->text));
-}
-
 /**
  * adw_entry_row_grab_focus_without_selecting:
  * @self: an entry row
