@@ -12,7 +12,6 @@
 
 #include "adw-animation-util.h"
 #include "adw-gizmo-private.h"
-#include "adw-macros-private.h"
 #include "adw-shadow-helper-private.h"
 #include "adw-spring-animation.h"
 #include "adw-swipeable.h"
@@ -80,8 +79,6 @@
  *
  * `AdwFlap` has a single CSS node with name `flap`. The node will get the style
  * classes `.folded` when it is folded, and `.unfolded` when it's not.
- *
- * Since: 1.0
  */
 
 /**
@@ -93,8 +90,6 @@
  *   space.
  *
  * Describes the possible folding behavior of a [class@Flap] widget.
- *
- * Since: 1.0
  */
 
 /**
@@ -114,8 +109,6 @@
  * [property@Flap:swipe-to-open] and [property@Flap:swipe-to-close].
  *
  * New values may be added to this enum over time.
- *
- * Since: 1.0
  */
 
 typedef struct {
@@ -331,7 +324,7 @@ animate_reveal (AdwFlap *self,
                                        self->reveal_progress);
   adw_spring_animation_set_value_to (ADW_SPRING_ANIMATION (self->reveal_animation), to);
 
-  if (!G_APPROX_VALUE (self->reveal_progress, to, FLT_EPSILON))
+  if (!G_APPROX_VALUE (self->reveal_progress, to, DBL_EPSILON))
     adw_spring_animation_set_initial_velocity (ADW_SPRING_ANIMATION (self->reveal_animation),
                                                velocity / adw_swipeable_get_distance (ADW_SWIPEABLE (self)));
   else
@@ -363,8 +356,6 @@ static void
 set_folded (AdwFlap  *self,
             gboolean  folded)
 {
-  GtkStyleContext *context;
-
   folded = !!folded;
 
   if (self->folded == folded)
@@ -386,13 +377,12 @@ set_folded (AdwFlap  *self,
   if (!self->locked)
     set_reveal_flap (self, !self->folded, 0);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
   if (folded) {
-    gtk_style_context_add_class (context, "folded");
-    gtk_style_context_remove_class (context, "unfolded");
+    gtk_widget_add_css_class (GTK_WIDGET (self), "folded");
+    gtk_widget_remove_css_class (GTK_WIDGET (self), "unfolded");
   } else {
-    gtk_style_context_remove_class (context, "folded");
-    gtk_style_context_add_class (context, "unfolded");
+    gtk_widget_remove_css_class (GTK_WIDGET (self), "folded");
+    gtk_widget_add_css_class (GTK_WIDGET (self), "unfolded");
   }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLDED]);
@@ -412,10 +402,14 @@ static void
 begin_swipe_cb (AdwSwipeTracker *tracker,
                 AdwFlap         *self)
 {
-  if (self->reveal_progress <= 0 && !self->swipe_to_open)
+  if ((G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) ||
+       self->reveal_progress < 0) &&
+      !self->swipe_to_open)
     return;
 
-  if (self->reveal_progress >= 1 && !self->swipe_to_close)
+  if ((G_APPROX_VALUE (self->reveal_progress, 1, DBL_EPSILON) ||
+       self->reveal_progress > 1) &&
+      !self->swipe_to_close)
     return;
 
   adw_animation_pause (self->reveal_animation);
@@ -691,9 +685,10 @@ interpolate_reveal (AdwFlap  *self,
                     int      *content_size,
                     int      *separator_size)
 {
-  if (self->reveal_progress <= 0) {
+  
+  if (G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) || self->reveal_progress < 0) {
     compute_sizes (self, width, height, folded, FALSE, flap_size, content_size, separator_size);
-  } else if (self->reveal_progress >= 1) {
+  } else if (G_APPROX_VALUE (self->reveal_progress, 1, DBL_EPSILON) || self->reveal_progress > 1) {
     compute_sizes (self, width, height, folded, TRUE, flap_size, content_size, separator_size);
   } else {
     int flap_revealed, content_revealed, separator_revealed;
@@ -722,9 +717,9 @@ interpolate_fold (AdwFlap *self,
                   int     *content_size,
                   int     *separator_size)
 {
-  if (self->fold_progress <= 0) {
+  if (G_APPROX_VALUE (self->fold_progress, 0, DBL_EPSILON) || self->fold_progress < 0) {
     interpolate_reveal (self, width, height, FALSE, flap_size, content_size, separator_size);
-  } else if (self->fold_progress >= 1) {
+  } else if (G_APPROX_VALUE (self->fold_progress, 1, DBL_EPSILON) || self->fold_progress > 1) {
     interpolate_reveal (self, width, height, TRUE, flap_size, content_size, separator_size);
   } else {
     int flap_folded, content_folded, separator_folded;
@@ -988,7 +983,7 @@ adw_flap_measure (GtkWidget      *widget,
     }
 
     min = MAX (content_min + (int) round ((flap_min + separator_min) * min_progress), flap_min);
-    nat = MAX (content_nat + (int) round ((flap_nat + separator_nat) * nat_progress), flap_nat);
+    nat = MAX (content_nat + (int) round ((flap_nat + separator_min) * nat_progress), flap_nat);
   } else {
     min = MAX (MAX (content_min, flap_min), separator_min);
     nat = MAX (MAX (content_nat, flap_nat), separator_nat);
@@ -1230,9 +1225,10 @@ adw_flap_dispose (GObject *object)
 {
   AdwFlap *self = ADW_FLAP (object);
 
-  g_clear_pointer (&self->flap.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->separator.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->content.widget, gtk_widget_unparent);
+  adw_flap_set_flap (self, NULL);
+  adw_flap_set_separator (self, NULL);
+  adw_flap_set_content (self, NULL);
+
   g_clear_pointer (&self->shield, gtk_widget_unparent);
 
   g_clear_object (&self->shadow_helper);
@@ -1268,8 +1264,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The content widget.
    *
    * It's always displayed when unfolded, and partially visible when folded.
-   *
-   * Since: 1.0
    */
   props[PROP_CONTENT] =
     g_param_spec_object ("content", NULL, NULL,
@@ -1282,8 +1276,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The flap widget.
    *
    * It's only visible when [property@Flap:reveal-progress] is greater than 0.
-   *
-   * Since: 1.0
    */
   props[PROP_FLAP] =
     g_param_spec_object ("flap", NULL, NULL,
@@ -1298,8 +1290,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * It's displayed between content and flap when there's no shadow to display.
    * When exactly it's visible depends on the [property@Flap:transition-type]
    * value.
-   *
-   * Since: 1.0
    */
   props[PROP_SEPARATOR] =
     g_param_spec_object ("separator", NULL, NULL,
@@ -1313,8 +1303,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
    * if `GTK_PACK_END`, it's displayed after the content.
-   *
-   * Since: 1.0
    */
   props[PROP_FLAP_POSITION] =
     g_param_spec_enum ("flap-position", NULL, NULL,
@@ -1326,8 +1314,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * AdwFlap:reveal-flap: (attributes org.gtk.Property.get=adw_flap_get_reveal_flap org.gtk.Property.set=adw_flap_set_reveal_flap)
    *
    * Whether the flap widget is revealed.
-   *
-   * Since: 1.0
    */
   props[PROP_REVEAL_FLAP] =
     g_param_spec_boolean ("reveal-flap", NULL, NULL,
@@ -1344,8 +1330,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * ```c
    * adw_spring_params_new (1, 0.5, 500)
    * ```
-   *
-   * Since: 1.0
    */
   props[PROP_REVEAL_PARAMS] =
     g_param_spec_boxed ("reveal-params", NULL, NULL,
@@ -1360,8 +1344,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * 0 means fully hidden, 1 means fully revealed.
    *
    * See [property@Flap:reveal-flap].
-   *
-   * Since: 1.0
    */
   props[PROP_REVEAL_PROGRESS] =
     g_param_spec_double ("reveal-progress", NULL, NULL,
@@ -1369,11 +1351,9 @@ adw_flap_class_init (AdwFlapClass *klass)
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy org.gtk.Property.set=adw_flap_set_fold_policy)
+   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy)
    *
    * The fold policy for the flap.
-   *
-   * Since: 1.0
    */
   props[PROP_FOLD_POLICY] =
     g_param_spec_enum ("fold-policy", NULL, NULL,
@@ -1392,8 +1372,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * This can be useful if you have a long ellipsizing label and want to let it
    * ellipsize instead of immediately folding.
-   *
-   * Since: 1.0
    */
   props[PROP_FOLD_THRESHOLD_POLICY] =
     g_param_spec_enum ("fold-threshold-policy", NULL, NULL,
@@ -1405,8 +1383,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * AdwFlap:fold-duration: (attributes org.gtk.Property.get=adw_flap_get_fold_duration org.gtk.Property.set=adw_flap_set_fold_duration)
    *
    * The fold transition animation duration, in milliseconds.
-   *
-   * Since: 1.0
    */
   props[PROP_FOLD_DURATION] =
     g_param_spec_uint ("fold-duration", NULL, NULL,
@@ -1420,8 +1396,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Whether the flap is currently folded.
    *
    * See [property@Flap:fold-policy].
-   *
-   * Since: 1.0
    */
   props[PROP_FOLDED] =
     g_param_spec_boolean ("folded", NULL, NULL,
@@ -1436,8 +1410,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * If `FALSE`, folding when the flap is revealed automatically closes it, and
    * unfolding it when the flap is not revealed opens it. If `TRUE`,
    * [property@Flap:reveal-flap] value never changes on its own.
-   *
-   * Since: 1.0
    */
   props[PROP_LOCKED] =
     g_param_spec_boolean ("locked", NULL, NULL,
@@ -1453,8 +1425,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * will be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions;
    * add the [`.background`](style-classes.html#background) style class to it if
    * this is unwanted.
-   *
-   * Since: 1.0
    */
   props[PROP_TRANSITION_TYPE] =
     g_param_spec_enum ("transition-type", NULL, NULL,
@@ -1470,8 +1440,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    * If `TRUE`, clicking the content widget while flap is revealed, as well as
    * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks
    * are passed through to the content widget.
-   *
-   * Since: 1.0
    */
   props[PROP_MODAL] =
     g_param_spec_boolean ("modal", NULL, NULL,
@@ -1485,8 +1453,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
-   *
-   * Since: 1.0
    */
   props[PROP_SWIPE_TO_OPEN] =
     g_param_spec_boolean ("swipe-to-open", NULL, NULL,
@@ -1500,8 +1466,6 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
-   *
-   * Since: 1.0
    */
   props[PROP_SWIPE_TO_CLOSE] =
     g_param_spec_boolean ("swipe-to-close", NULL, NULL,
@@ -1520,7 +1484,10 @@ adw_flap_class_init (AdwFlapClass *klass)
 static gboolean
 flap_close_cb (AdwFlap *self)
 {
-  if (self->reveal_progress <= 0 || self->fold_progress <= 0)
+  if (G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) ||
+      self->reveal_progress < 0 ||
+      G_APPROX_VALUE (self->fold_progress, 0, DBL_EPSILON) ||
+      self->fold_progress < 0)
     return GDK_EVENT_PROPAGATE;
 
   adw_flap_set_reveal_flap (ADW_FLAP (self), FALSE);
@@ -1531,7 +1498,6 @@ flap_close_cb (AdwFlap *self)
 static void
 adw_flap_init (AdwFlap *self)
 {
-  GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (self));
   GtkEventController *gesture;
   GtkShortcut *shortcut;
   AdwAnimationTarget *target;
@@ -1581,7 +1547,7 @@ adw_flap_init (AdwFlap *self)
 
   gtk_widget_set_overflow (GTK_WIDGET (self), GTK_OVERFLOW_HIDDEN);
 
-  gtk_style_context_add_class (context, "unfolded");
+  gtk_widget_add_css_class (GTK_WIDGET (self), "unfolded");
 
   target = adw_callback_animation_target_new ((AdwAnimationTargetFunc)
                                               fold_animation_value_cb,
@@ -1733,7 +1699,8 @@ adw_flap_get_swipe_area (AdwSwipeable           *swipeable,
   content_factor = transition_get_content_motion_factor (self);
 
   if (!is_drag ||
-      (flap_factor >= 1 && content_factor >= 1) ||
+      ((G_APPROX_VALUE (flap_factor, 1, DBL_EPSILON) || flap_factor > 1) &&
+       (G_APPROX_VALUE (content_factor, 1, DBL_EPSILON) || content_factor > 1)) ||
       (self->fold_progress < 1 && flap_factor > 0)) {
     rect->x = 0;
     rect->y = 0;
@@ -1792,8 +1759,6 @@ adw_flap_swipeable_init (AdwSwipeableInterface *iface)
  * Creates a new `AdwFlap`.
  *
  * Returns: the newly created `AdwFlap`
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_flap_new (void)
@@ -1808,8 +1773,6 @@ adw_flap_new (void)
  * Gets the content widget for @self.
  *
  * Returns: (transfer none) (nullable): the content widget for @self
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_content (AdwFlap *self)
@@ -1827,8 +1790,6 @@ adw_flap_get_content (AdwFlap *self)
  * Sets the content widget for @self.
  *
  * It's always displayed when unfolded, and partially visible when folded.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_content (AdwFlap   *self,
@@ -1860,8 +1821,6 @@ adw_flap_set_content (AdwFlap   *self,
  * Gets the flap widget for @self.
  *
  * Returns: (transfer none) (nullable): the flap widget for @self
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_flap (AdwFlap *self)
@@ -1879,8 +1838,6 @@ adw_flap_get_flap (AdwFlap *self)
  * Sets the flap widget for @self.
  *
  * It's only visible when [property@Flap:reveal-progress] is greater than 0.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_flap (AdwFlap   *self,
@@ -1913,8 +1870,6 @@ adw_flap_set_flap (AdwFlap   *self,
  * Gets the separator widget for @self.
  *
  * Returns: (transfer none) (nullable): the separator widget for @self
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_separator (AdwFlap *self)
@@ -1934,8 +1889,6 @@ adw_flap_get_separator (AdwFlap *self)
  * It's displayed between content and flap when there's no shadow to display.
  * When exactly it's visible depends on the [property@Flap:transition-type]
  * value.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_separator (AdwFlap   *self,
@@ -1967,8 +1920,6 @@ adw_flap_set_separator (AdwFlap   *self,
  * Gets the flap position for @self.
  *
  * Returns: the flap position for @self
- *
- * Since: 1.0
  */
 GtkPackType
 adw_flap_get_flap_position (AdwFlap *self)
@@ -1987,8 +1938,6 @@ adw_flap_get_flap_position (AdwFlap *self)
  *
  * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
  * if `GTK_PACK_END`, it's displayed after the content.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_flap_position (AdwFlap     *self,
@@ -2015,8 +1964,6 @@ adw_flap_set_flap_position (AdwFlap     *self,
  * Gets whether the flap widget is revealed for @self.
  *
  * Returns: `TRUE` if the flap widget is revealed
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_reveal_flap (AdwFlap *self)
@@ -2032,8 +1979,6 @@ adw_flap_get_reveal_flap (AdwFlap *self)
  * @reveal_flap: whether to reveal the flap widget
  *
  * Sets whether the flap widget is revealed for @self.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_reveal_flap (AdwFlap  *self,
@@ -2051,8 +1996,6 @@ adw_flap_set_reveal_flap (AdwFlap  *self,
  * Gets the reveal animation spring parameters for @self.
  *
  * Returns: the reveal animation parameters
- *
- * Since: 1.0
  */
 AdwSpringParams *
 adw_flap_get_reveal_params (AdwFlap *self)
@@ -2074,8 +2017,6 @@ adw_flap_get_reveal_params (AdwFlap *self)
  * ```c
  * adw_spring_params_new (1, 0.5, 500)
  * ```
- *
- * Since: 1.0
  */
 void
 adw_flap_set_reveal_params (AdwFlap         *self,
@@ -2104,8 +2045,6 @@ adw_flap_set_reveal_params (AdwFlap         *self,
  * See [property@Flap:reveal-flap].
  *
  * Returns: the current reveal progress for @self
- *
- * Since: 1.0
  */
 double
 adw_flap_get_reveal_progress (AdwFlap *self)
@@ -2122,8 +2061,6 @@ adw_flap_get_reveal_progress (AdwFlap *self)
  * Gets the fold policy for @self.
  *
  * Returns: the fold policy for @self
- *
- * Since: 1.0
  */
 AdwFlapFoldPolicy
 adw_flap_get_fold_policy (AdwFlap *self)
@@ -2139,8 +2076,6 @@ adw_flap_get_fold_policy (AdwFlap *self)
  * @policy: the fold policy
  *
  * Sets the fold policy for @self.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_fold_policy (AdwFlap           *self,
@@ -2179,8 +2114,6 @@ adw_flap_set_fold_policy (AdwFlap           *self,
  * @self: a flap
  *
  * Gets the fold threshold policy for @self.
- *
- * Since: 1.0
  */
 AdwFoldThresholdPolicy
 adw_flap_get_fold_threshold_policy (AdwFlap *self)
@@ -2203,8 +2136,6 @@ adw_flap_get_fold_threshold_policy (AdwFlap *self)
  *
  * This can be useful if you have a long ellipsizing label and want to let it
  * ellipsize instead of immediately folding.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_fold_threshold_policy (AdwFlap                *self,
@@ -2230,8 +2161,6 @@ adw_flap_set_fold_threshold_policy (AdwFlap                *self,
  * Gets the fold transition animation duration for @self, in milliseconds.
  *
  * Returns: the fold transition duration
- *
- * Since: 1.0
  */
 guint
 adw_flap_get_fold_duration (AdwFlap *self)
@@ -2247,8 +2176,6 @@ adw_flap_get_fold_duration (AdwFlap *self)
  * @duration: the new duration, in milliseconds
  *
  * Sets the fold transition animation duration for @self, in milliseconds.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_fold_duration (AdwFlap *self,
@@ -2273,8 +2200,6 @@ adw_flap_set_fold_duration (AdwFlap *self,
  * See [property@Flap:fold-policy].
  *
  * Returns: `TRUE` if @self is currently folded
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_folded (AdwFlap *self)
@@ -2291,8 +2216,6 @@ adw_flap_get_folded (AdwFlap *self)
  * Gets whether @self is locked.
  *
  * Returns: `TRUE` if @self is locked
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_locked (AdwFlap *self)
@@ -2312,8 +2235,6 @@ adw_flap_get_locked (AdwFlap *self)
  * If `FALSE`, folding when the flap is revealed automatically closes it, and
  * unfolding it when the flap is not revealed opens it. If `TRUE`,
  * [property@Flap:reveal-flap] value never changes on its own.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_locked (AdwFlap  *self,
@@ -2338,8 +2259,6 @@ adw_flap_set_locked (AdwFlap  *self,
  * Gets the type of animation used for reveal and fold transitions in @self.
  *
  * Returns: the current transition type of @self
- *
- * Since: 1.0
  */
 AdwFlapTransitionType
 adw_flap_get_transition_type (AdwFlap *self)
@@ -2360,8 +2279,6 @@ adw_flap_get_transition_type (AdwFlap *self)
  * be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions; add the
  * [`.background`](style-classes.html#background) style class to it if this is
  * unwanted.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_transition_type (AdwFlap               *self,
@@ -2390,8 +2307,6 @@ adw_flap_set_transition_type (AdwFlap               *self,
  * Gets whether @self is modal.
  *
  * Returns: `TRUE` if @self is modal
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_modal (AdwFlap *self)
@@ -2411,8 +2326,6 @@ adw_flap_get_modal (AdwFlap *self)
  * If `TRUE`, clicking the content widget while flap is revealed, as well as
  * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks are
  * passed through to the content widget.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_modal (AdwFlap  *self,
@@ -2442,8 +2355,6 @@ adw_flap_set_modal (AdwFlap  *self,
  * Gets whether @self can be opened with a swipe gesture.
  *
  * Returns: `TRUE` if @self can be opened with a swipe gesture
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_swipe_to_open (AdwFlap *self)
@@ -2462,8 +2373,6 @@ adw_flap_get_swipe_to_open (AdwFlap *self)
  *
  * The area that can be swiped depends on the [property@Flap:transition-type]
  * value.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_swipe_to_open (AdwFlap  *self,
@@ -2490,8 +2399,6 @@ adw_flap_set_swipe_to_open (AdwFlap  *self,
  * Gets whether @self can be closed with a swipe gesture.
  *
  * Returns: `TRUE` if @self can be closed with a swipe gesture
- *
- * Since: 1.0
  */
 gboolean
 adw_flap_get_swipe_to_close (AdwFlap *self)
@@ -2510,8 +2417,6 @@ adw_flap_get_swipe_to_close (AdwFlap *self)
  *
  * The area that can be swiped depends on the [property@Flap:transition-type]
  * value.
- *
- * Since: 1.0
  */
 void
 adw_flap_set_swipe_to_close (AdwFlap  *self,
