@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1+
  *
- * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
+ * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
  */
 
 #include "config.h"
@@ -26,7 +26,7 @@
 #define SCROLL_ANIMATION_DURATION 200
 #define TRANSITION_DURATION 400
 #define THUMBNAIL_BORDER_RADIUS 12
-#define WINDOW_BORDER_RADIUS 15
+#define WINDOW_BORDER_RADIUS 12
 
 /**
  * AdwTabOverview:
@@ -125,8 +125,6 @@ struct _AdwTabOverview
   GtkWidget *transition_picture;
   gboolean transition_pinned;
 
-  GdkDragAction extra_drag_preferred_action;
-
   GtkWidget *last_focus;
 };
 
@@ -149,7 +147,6 @@ enum {
   PROP_SECONDARY_MENU,
   PROP_SHOW_START_TITLE_BUTTONS,
   PROP_SHOW_END_TITLE_BUTTONS,
-  PROP_EXTRA_DRAG_PREFERRED_ACTION,
   PROP_EXTRA_DRAG_PRELOAD,
   LAST_PROP
 };
@@ -163,12 +160,6 @@ enum {
   SIGNAL_LAST_SIGNAL,
 };
 
-typedef enum {
-  ANIMATION_NONE,
-  ANIMATION_IN,
-  ANIMATION_OUT,
-} AnimationDirection;
-
 static guint signals[SIGNAL_LAST_SIGNAL];
 
 #define ADW_TYPE_TAB_OVERVIEW_SCROLLABLE (adw_tab_overview_scrollable_get_type ())
@@ -537,18 +528,19 @@ adw_tab_overview_scrollable_size_allocate (GtkWidget *widget,
   /* The value may have changed during gtk_adjustment_configure() */
   value = floor (gtk_adjustment_get_value (self->vadjustment));
 
+  if (G_APPROX_VALUE (value, 0, DBL_EPSILON))
+    gtk_widget_add_css_class (self->overview, "scrolled-to-top");
+  else
+    gtk_widget_remove_css_class (self->overview, "scrolled-to-top");
+
   adw_tab_grid_set_visible_range (ADW_TAB_GRID (self->pinned_grid),
                                   CLAMP (value - self->pinned_grid_pos, 0, pinned_height),
                                   CLAMP (value - self->pinned_grid_pos + height - new_button_height, 0, pinned_height),
-                                  height - new_button_height,
-                                  0,
-                                  CLAMP (self->pinned_grid_pos + pinned_height - height + new_button_height - value, 0, new_button_height));
+                                  height - new_button_height);
   adw_tab_grid_set_visible_range (ADW_TAB_GRID (self->grid),
                                   CLAMP (value - self->grid_pos, 0, grid_height),
                                   CLAMP (value - self->grid_pos + height - new_button_height, 0, grid_height),
-                                  height - new_button_height,
-                                  0,
-                                  CLAMP (self->grid_pos + grid_height - height + new_button_height - value, 0, new_button_height));
+                                  height - new_button_height);
 
   if (self->scroll_animation_done) {
     g_clear_pointer (&self->scroll_animation_grid, adw_tab_grid_reset_scrolled_tab);
@@ -729,34 +721,18 @@ adw_tab_overview_scrollable_init (AdwTabOverviewScrollable *self)
   self->scroll_animation =
     adw_timed_animation_new (GTK_WIDGET (self), 0, 1,
                              SCROLL_ANIMATION_DURATION, target);
-
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (self->scroll_animation), ADW_EASE);
-
   g_signal_connect_swapped (self->scroll_animation, "done",
                             G_CALLBACK (scroll_animation_done_cb), self);
 }
 
-static void
-set_extra_drag_preferred_action (AdwTabOverview *self,
-                                 GdkDragAction   preferred_action)
-{
-  self->extra_drag_preferred_action = preferred_action;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_DRAG_PREFERRED_ACTION]);
-}
-
-
 static gboolean
 extra_drag_drop_cb (AdwTabOverview *self,
                     AdwTabPage     *page,
-                    GValue         *value,
-                    GdkDragAction   preferred_action)
+                    GValue         *value)
 {
   gboolean ret = GDK_EVENT_PROPAGATE;
 
-  set_extra_drag_preferred_action (self, preferred_action);
   g_signal_emit (self, signals[SIGNAL_EXTRA_DRAG_DROP], 0, page, value, &ret);
-  set_extra_drag_preferred_action (self, 0);
 
   return ret;
 }
@@ -773,13 +749,6 @@ extra_drag_value_cb (AdwTabOverview *self,
   return preferred_action;
 }
 
-static GdkDragAction
-extra_drag_value_notify (AdwTabOverview *self,
-                         GValue         *value)
-{
-  return GDK_ACTION_ALL;
-}
-
 static void
 empty_changed_cb (AdwTabOverview *self)
 {
@@ -927,8 +896,7 @@ notify_n_pages_cb (AdwTabOverview *self)
 
   n_pages = adw_tab_view_get_n_pages (self->view);
 
-  /* Translators: Tab overview title, %u is the number of open tabs */
-  title_str = g_strdup_printf (dngettext (GETTEXT_PACKAGE, "%u Tab", "%u Tabs", n_pages), n_pages);
+  title_str = g_strdup_printf (ngettext ("%u Tab", "%u Tabs", n_pages), n_pages);
 
   adw_window_title_set_title (ADW_WINDOW_TITLE (self->title), title_str);
 
@@ -987,17 +955,15 @@ open_animation_value_cb (double          value,
 }
 
 static void
-set_overview_visible (AdwTabOverview     *self,
-                      gboolean            visible,
-                      AnimationDirection  direction)
+set_overview_visible (AdwTabOverview *self,
+                      gboolean        visible,
+                      gboolean        animating)
 {
-  gboolean animating = direction != ANIMATION_NONE;
-
   gtk_widget_set_child_visible (self->overview, visible || animating);
   gtk_widget_set_can_target (self->overview, visible);
   gtk_widget_set_can_focus (self->overview, visible);
   gtk_widget_set_can_target (self->child_bin, !visible && !animating);
-  gtk_widget_set_can_focus (self->child_bin, !visible && direction != ANIMATION_IN);
+  gtk_widget_set_can_focus (self->child_bin, !visible && !animating);
 
   if (visible || animating)
     gtk_widget_add_css_class (self->child_bin, "background");
@@ -1015,7 +981,7 @@ open_animation_done_cb (AdwTabOverview *self)
     self->transition_thumbnail = NULL;
   }
 
-  set_overview_visible (self, self->is_open, ANIMATION_NONE);
+  set_overview_visible (self, self->is_open, FALSE);
 
   if (!self->is_open) {
     adw_tab_view_close_overview (self->view);
@@ -1024,7 +990,10 @@ open_animation_done_cb (AdwTabOverview *self)
 
     if (self->last_focus) {
       gtk_widget_grab_focus (self->last_focus);
-      g_clear_weak_pointer (&self->last_focus);
+
+      g_object_remove_weak_pointer (G_OBJECT (self->last_focus),
+                                    (gpointer *) &self->last_focus);
+      self->last_focus = NULL;
     }
   }
 
@@ -1032,14 +1001,6 @@ open_animation_done_cb (AdwTabOverview *self)
   gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
-static inline double
-inverse_lerp (double a,
-              double b,
-              double t)
-{
-  return (t - a) / (b - a);
-}
-
 static void
 calculate_bounds (AdwTabOverview  *self,
                   graphene_rect_t *bounds,
@@ -1089,18 +1050,11 @@ calculate_bounds (AdwTabOverview  *self,
                       adw_lerp (1, thumbnail_bounds.size.width / view_bounds.size.width, self->progress),
                       adw_lerp (1, thumbnail_bounds.size.height / view_bounds.size.height, self->progress));
 
-  graphene_size_init (&transition_bounds->size,
+  graphene_rect_init (transition_bounds,
+                      adw_lerp (0, thumbnail_bounds.origin.x, self->progress),
+                      adw_lerp (0, thumbnail_bounds.origin.y, self->progress),
                       clip_bounds->size.width * clip_scale->width,
                       clip_bounds->size.height * clip_scale->height);
-  graphene_point_init (&transition_bounds->origin,
-                       adw_lerp (0, thumbnail_bounds.origin.x,
-                                 inverse_lerp (bounds->size.width,
-                                               thumbnail_bounds.size.width,
-                                               transition_bounds->size.width)),
-                       adw_lerp (0, thumbnail_bounds.origin.y,
-                                 inverse_lerp (bounds->size.height,
-                                               thumbnail_bounds.size.height,
-                                               transition_bounds->size.height)));
 }
 
 static void
@@ -1364,7 +1318,11 @@ adw_tab_overview_dispose (GObject *object)
 {
   AdwTabOverview *self = ADW_TAB_OVERVIEW (object);
 
-  g_clear_weak_pointer (&self->last_focus);
+  if (self->last_focus) {
+    g_object_remove_weak_pointer (G_OBJECT (self->last_focus),
+                                  (gpointer *) &self->last_focus);
+    self->last_focus = NULL;
+  }
 
   adw_tab_overview_set_view (self, NULL);
 
@@ -1414,9 +1372,6 @@ adw_tab_overview_get_property (GObject    *object,
   case PROP_SHOW_END_TITLE_BUTTONS:
     g_value_set_boolean (value, adw_tab_overview_get_show_end_title_buttons (self));
     break;
-  case PROP_EXTRA_DRAG_PREFERRED_ACTION:
-    g_value_set_flags (value, adw_tab_overview_get_extra_drag_preferred_action (self));
-    break;
   case PROP_EXTRA_DRAG_PRELOAD:
     g_value_set_boolean (value, adw_tab_overview_get_extra_drag_preload (self));
     break;
@@ -1504,15 +1459,6 @@ escape_cb (AdwTabOverview *self)
   return GDK_EVENT_STOP;
 }
 
-static void
-start_search_cb (AdwTabOverview *self)
-{
-  if (gtk_widget_get_child_visible (self->overview)) {
-    gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (self->search_bar), TRUE);
-    gtk_widget_grab_focus (self->search_entry);
-  }
-}
-
 static gboolean
 object_handled_accumulator (GSignalInvocationHint *ihint,
                             GValue                *return_accu,
@@ -1541,7 +1487,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
   widget_class->focus = adw_tab_overview_focus;
 
   /**
-   * AdwTabOverview:view:
+   * AdwTabOverview:view: (attributes org.gtk.Property.get=adw_tab_overview_get_view org.gtk.Property.set=adw_tab_overview_set_view)
    *
    * The tab view the overview controls.
    *
@@ -1555,7 +1501,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:child:
+   * AdwTabOverview:child: (attributes org.gtk.Property.get=adw_tab_overview_get_child org.gtk.Property.set=adw_tab_overview_set_child)
    *
    * The child widget.
    *
@@ -1567,7 +1513,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:open:
+   * AdwTabOverview:open: (attributes org.gtk.Property.get=adw_tab_overview_get_open org.gtk.Property.set=adw_tab_overview_set_open)
    *
    * Whether the overview is open.
    *
@@ -1579,7 +1525,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:inverted:
+   * AdwTabOverview:inverted: (attributes org.gtk.Property.get=adw_tab_overview_get_inverted org.gtk.Property.set=adw_tab_overview_set_inverted)
    *
    * Whether thumbnails use inverted layout.
    *
@@ -1594,7 +1540,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:enable-search:
+   * AdwTabOverview:enable-search: (attributes org.gtk.Property.get=adw_tab_overview_get_enable_search org.gtk.Property.set=adw_tab_overview_set_enable_search)
    *
    * Whether to enable search in tabs.
    *
@@ -1615,7 +1561,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:search-active:
+   * AdwTabOverview:search-active: (attributes org.gtk.Property.get=adw_tab_overview_get_search_active)
    *
    * Whether search is currently active.
    *
@@ -1629,7 +1575,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwTabOverview:enable-new-tab:
+   * AdwTabOverview:enable-new-tab: (attributes org.gtk.Property.get=adw_tab_overview_get_enable_new_tab org.gtk.Property.set=adw_tab_overview_set_enable_new_tab)
    *
    * Whether to enable new tab button.
    *
@@ -1643,7 +1589,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:secondary-menu:
+   * AdwTabOverview:secondary-menu: (attributes org.gtk.Property.get=adw_tab_overview_get_secondary_menu org.gtk.Property.set=adw_tab_overview_set_secondary_menu)
    *
    * The secondary menu model.
    *
@@ -1657,7 +1603,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:show-start-title-buttons:
+   * AdwTabOverview:show-start-title-buttons: (attributes org.gtk.Property.get=adw_tab_overview_get_show_start_title_buttons org.gtk.Property.set=adw_tab_overview_set_show_start_title_buttons)
    *
    * Whether to show start title buttons in the overview's header bar.
    *
@@ -1671,7 +1617,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:show-end-title-buttons:
+   * AdwTabOverview:show-end-title-buttons: (attributes org.gtk.Property.get=adw_tab_overview_get_show_end_title_buttons org.gtk.Property.set=adw_tab_overview_set_show_end_title_buttons)
    *
    * Whether to show end title buttons in the overview's header bar.
    *
@@ -1685,24 +1631,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwTabOverview:extra-drag-preferred-action:
-   *
-   * The unique action on the `current-drop` of the
-   * [signal@TabOverview::extra-drag-drop].
-   *
-   * This property should only be used during a
-   * [signal@TabOverview::extra-drag-drop] and is always a subset of what was
-   * originally passed to [method@TabOverview.setup_extra_drop_target].
-   *
-   * Since: 1.4
-   */
-  props[PROP_EXTRA_DRAG_PREFERRED_ACTION] =
-    g_param_spec_flags ("extra-drag-preferred-action", NULL, NULL,
-                       GDK_TYPE_DRAG_ACTION, 0,
-                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * AdwTabOverview:extra-drag-preload:
+   * AdwTabOverview:extra-drag-preload: (attributes org.gtk.Property.get=adw_tab_overview_get_extra_drag_preload org.gtk.Property.set=adw_tab_overview_set_extra_drag_preload)
    *
    * Whether the drop data should be preloaded on hover.
    *
@@ -1721,7 +1650,7 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
    * AdwTabOverview::create-tab:
    * @self: a tab overview
    *
-   * Emitted when a tab needs to be created.
+   * Emitted when a tab needs to be created;
    *
    * This can happen after the new tab button has been pressed, see
    * [property@TabOverview:enable-new-tab].
@@ -1814,13 +1743,6 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
                                    (GtkWidgetActionActivateFunc) overview_close_cb);
   gtk_widget_class_add_binding (widget_class, GDK_KEY_Escape, 0,
                                 (GtkShortcutFunc) escape_cb, NULL);
-#ifdef __APPLE__
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_f, GDK_META_MASK,
-                                (GtkShortcutFunc) start_search_cb, NULL);
-#else
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_f, GDK_CONTROL_MASK,
-                                (GtkShortcutFunc) start_search_cb, NULL);
-#endif
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-tab-overview.ui");
@@ -1849,9 +1771,6 @@ adw_tab_overview_class_init (AdwTabOverviewClass *klass)
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
   gtk_widget_class_set_css_name (widget_class, "taboverview");
 
-  g_signal_override_class_handler ("extra-drag-value", G_TYPE_FROM_CLASS (klass),
-                                   G_CALLBACK (extra_drag_value_notify));
-
   g_type_ensure (ADW_TYPE_TAB_GRID);
   g_type_ensure (ADW_TYPE_TAB_OVERVIEW_SCROLLABLE);
 }
@@ -1879,8 +1798,6 @@ adw_tab_overview_init (AdwTabOverview *self)
                              TRANSITION_DURATION,
                              target);
 
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (self->open_animation), ADW_EASE);
-
   g_signal_connect_swapped (self->open_animation, "done",
                             G_CALLBACK (open_animation_done_cb), self);
 }
@@ -1925,7 +1842,7 @@ adw_tab_overview_new (void)
 }
 
 /**
- * adw_tab_overview_get_view:
+ * adw_tab_overview_get_view: (attributes org.gtk.Method.get_property=view)
  * @self: a tab overview
  *
  * Gets the tab view @self controls.
@@ -1943,7 +1860,7 @@ adw_tab_overview_get_view (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_view:
+ * adw_tab_overview_set_view: (attributes org.gtk.Method.set_property=view)
  * @self: a tab overview
  * @view: (nullable): a tab view
  *
@@ -2021,8 +1938,8 @@ adw_tab_overview_set_view (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_child:
- * @self: a tab overview
+ * adw_tab_overview_get_child: (attributes org.gtk.Method.get_property=child)
+ * @self: a `AdwTabOveview`
  *
  * Gets the child widget of @self.
  *
@@ -2039,7 +1956,7 @@ adw_tab_overview_get_child (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_child:
+ * adw_tab_overview_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a tab overview
  * @child: (nullable): the child widget
  *
@@ -2057,16 +1974,13 @@ adw_tab_overview_set_child (AdwTabOverview *self,
   if (child == adw_tab_overview_get_child (self))
     return;
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   adw_bin_set_child (ADW_BIN (self->child_bin), child);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CHILD]);
 }
 
 /**
- * adw_tab_overview_get_open:
+ * adw_tab_overview_get_open: (attributes org.gtk.Method.get_property=open)
  * @self: a tab overview
  *
  * Gets whether @self is open.
@@ -2084,7 +1998,7 @@ adw_tab_overview_get_open (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_open:
+ * adw_tab_overview_set_open: (attributes org.gtk.Method.set_property=open)
  * @self: a tab overview
  * @open: whether the overview is open
  *
@@ -2143,16 +2057,24 @@ adw_tab_overview_set_open (AdwTabOverview *self,
     if (gtk_widget_get_root (GTK_WIDGET (self)))
       focus = gtk_root_get_focus (gtk_widget_get_root (GTK_WIDGET (self)));
 
-    if (focus && gtk_widget_is_ancestor (focus, self->child_bin))
-      g_set_weak_pointer (&self->last_focus, focus);
+    if (focus && gtk_widget_is_ancestor (focus, self->child_bin)) {
+      if (self->last_focus)
+        g_object_remove_weak_pointer (G_OBJECT (self->last_focus),
+                                      (gpointer *)& self->last_focus);
+
+      self->last_focus = focus;
+
+      g_object_add_weak_pointer (G_OBJECT (self->last_focus),
+                                 (gpointer *) &self->last_focus);
+    }
 
     adw_tab_view_open_overview (self->view);
 
-    set_overview_visible (self, self->is_open, ANIMATION_IN);
+    set_overview_visible (self, self->is_open, TRUE);
 
     adw_tab_grid_try_focus_selected_tab (grid, FALSE);
   } else {
-    set_overview_visible (self, self->is_open, ANIMATION_OUT);
+    set_overview_visible (self, self->is_open, TRUE);
   }
 
   if (self->transition_picture)
@@ -2174,7 +2096,7 @@ adw_tab_overview_set_open (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_inverted:
+ * adw_tab_overview_get_inverted: (attributes org.gtk.Method.get_property=inverted)
  * @self: a tab overview
  *
  * Gets whether thumbnails use inverted layout.
@@ -2192,7 +2114,7 @@ adw_tab_overview_get_inverted (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_inverted:
+ * adw_tab_overview_set_inverted: (attributes org.gtk.Method.set_property=inverted)
  * @self: a tab overview
  * @inverted: whether thumbnails use inverted layout
  *
@@ -2221,7 +2143,7 @@ adw_tab_overview_set_inverted (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_enable_search:
+ * adw_tab_overview_get_enable_search: (attributes org.gtk.Method.get_property=enable-search)
  * @self: a tab overview
  *
  * Gets whether search in tabs is enabled for @self.
@@ -2239,7 +2161,7 @@ adw_tab_overview_get_enable_search (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_enable_search:
+ * adw_tab_overview_set_enable_search: (attributes org.gtk.Method.set_property=enable-search)
  * @self: a tab overview
  * @enable_search: whether to enable search
  *
@@ -2281,7 +2203,7 @@ adw_tab_overview_set_enable_search (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_search_active:
+ * adw_tab_overview_get_search_active: (attributes org.gtk.Method.get_property=search-active)
  * @self: a tab overview
  *
  * Gets whether search is currently active for @self.
@@ -2301,7 +2223,7 @@ adw_tab_overview_get_search_active (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_get_enable_new_tab:
+ * adw_tab_overview_get_enable_new_tab: (attributes org.gtk.Method.get_property=enable-new-tab)
  * @self: a tab overview
  *
  * Gets whether to new tab button is enabled for @self.
@@ -2319,7 +2241,7 @@ adw_tab_overview_get_enable_new_tab (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_enable_new_tab:
+ * adw_tab_overview_set_enable_new_tab: (attributes org.gtk.Method.set_property=enable-new-tab)
  * @self: a tab overview
  * @enable_new_tab: whether to enable new tab button
  *
@@ -2348,7 +2270,7 @@ adw_tab_overview_set_enable_new_tab (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_secondary_menu:
+ * adw_tab_overview_get_secondary_menu: (attributes org.gtk.Method.get_property=secondary-menu)
  * @self: a tab overview
  *
  * Gets the secondary menu model for @self.
@@ -2366,7 +2288,7 @@ adw_tab_overview_get_secondary_menu (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_secondary_menu:
+ * adw_tab_overview_set_secondary_menu: (attributes org.gtk.Method.set_property=secondary-menu)
  * @self: a tab overview
  * @secondary_menu: (nullable): a menu model
  *
@@ -2395,7 +2317,7 @@ adw_tab_overview_set_secondary_menu (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_show_start_title_buttons:
+ * adw_tab_overview_get_show_start_title_buttons: (attributes org.gtk.Method.get_property=show-start-title-buttons)
  * @self: a tab overview
  *
  * Gets whether start title buttons are shown in @self's header bar.
@@ -2413,7 +2335,7 @@ adw_tab_overview_get_show_start_title_buttons (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_show_start_title_buttons:
+ * adw_tab_overview_set_show_start_title_buttons: (attributes org.gtk.Method.set_property=show-start-title-buttons)
  * @self: a tab overview
  * @show_start_title_buttons: whether to show start title buttons
  *
@@ -2443,7 +2365,7 @@ adw_tab_overview_set_show_start_title_buttons (AdwTabOverview *self,
 }
 
 /**
- * adw_tab_overview_get_show_end_title_buttons:
+ * adw_tab_overview_get_show_end_title_buttons: (attributes org.gtk.Method.get_property=show-end-title-buttons)
  * @self: a tab overview
  *
  * Gets whether end title buttons are shown in @self's header bar.
@@ -2461,7 +2383,7 @@ adw_tab_overview_get_show_end_title_buttons (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_show_end_title_buttons:
+ * adw_tab_overview_set_show_end_title_buttons: (attributes org.gtk.Method.set_property=show-end-title-buttons)
  * @self: a tab overview
  * @show_end_title_buttons: whether to show end title buttons
  *
@@ -2543,25 +2465,7 @@ adw_tab_overview_get_pinned_tab_grid (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_get_extra_drag_preferred_action:
- * @self: a tab overview
- *
- * Gets the current action during a drop on the extra_drop_target.
- *
- * Returns: the drag action of the current drop.
- *
- * Since: 1.4
- */
-GdkDragAction
-adw_tab_overview_get_extra_drag_preferred_action (AdwTabOverview *self)
-{
-  g_return_val_if_fail (ADW_IS_TAB_OVERVIEW (self), 0);
-
-  return self->extra_drag_preferred_action;
-}
-
-/**
- * adw_tab_overview_get_extra_drag_preload:
+ * adw_tab_overview_get_extra_drag_preload: (attributes org.gtk.Method.get_property=extra-drag-preload)
  * @self: a tab overview
  *
  * Gets whether drop data should be preloaded on hover.
@@ -2579,7 +2483,7 @@ adw_tab_overview_get_extra_drag_preload (AdwTabOverview *self)
 }
 
 /**
- * adw_tab_overview_set_extra_drag_preload:
+ * adw_tab_overview_set_extra_drag_preload: (attributes org.gtk.Method.set_property=extra-drag-preload)
  * @self: a tab overview
  * @preload: whether to preload drop data
  *
