@@ -10,7 +10,6 @@
 
 #include "adw-animation-util.h"
 #include "adw-easing.h"
-#include "adw-macros-private.h"
 #include "adw-timed-animation.h"
 #include "adw-toast-private.h"
 #include "adw-toast-widget-private.h"
@@ -64,8 +63,6 @@
  * ## Accessibility
  *
  * `AdwToastOverlay` uses the `GTK_ACCESSIBLE_ROLE_TAB_GROUP` role.
- *
- * Since: 1.0
  */
 
 typedef struct {
@@ -77,6 +74,7 @@ typedef struct {
   AdwAnimation *show_animation;
   AdwAnimation *hide_animation;
 
+  gulong shown_id;
   gulong dismissed_id;
   gboolean postponing;
 } ToastInfo;
@@ -110,6 +108,8 @@ static GtkBuildableIface *parent_buildable_iface;
 static void
 free_toast_info (ToastInfo *info)
 {
+  if (info->shown_id && info->show_animation)
+    g_signal_handler_disconnect (info->show_animation, info->shown_id);
   if (info->dismissed_id && info->toast)
     g_signal_handler_disconnect (info->toast, info->dismissed_id);
 
@@ -256,8 +256,8 @@ show_toast (AdwToastOverlay *self,
                              self->hiding_toasts ? REPLACE_DURATION : SHOW_DURATION,
                              target);
 
-  g_signal_connect_swapped (info->show_animation, "done",
-                            G_CALLBACK (show_done_cb), info);
+  info->shown_id = g_signal_connect_swapped (info->show_animation, "done",
+                                             G_CALLBACK (show_done_cb), info);
 
   adw_animation_play (info->show_animation);
 }
@@ -493,7 +493,6 @@ adw_toast_overlay_class_init (AdwToastOverlayClass *klass)
   object_class->set_property = adw_toast_overlay_set_property;
 
   widget_class->compute_expand = adw_widget_compute_expand;
-  widget_class->get_request_mode = adw_widget_get_request_mode;
   widget_class->measure = adw_toast_overlay_measure;
   widget_class->size_allocate = adw_toast_overlay_size_allocate;
 
@@ -501,8 +500,6 @@ adw_toast_overlay_class_init (AdwToastOverlayClass *klass)
    * AdwToastOverlay:child: (attributes org.gtk.Property.get=adw_toast_overlay_get_child org.gtk.Property.set=adw_toast_overlay_set_child)
    *
    * The child widget.
-   *
-   * Since: 1.0
    */
   props[PROP_CHILD] =
     g_param_spec_object ("child", NULL, NULL,
@@ -555,8 +552,6 @@ adw_toast_overlay_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwToastOverlay`.
  *
  * Returns: the new created `AdwToastOverlay`
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_toast_overlay_new (void)
@@ -571,8 +566,6 @@ adw_toast_overlay_new (void)
  * Gets the child widget of @self.
  *
  * Returns: (nullable) (transfer none): the child widget of @self
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_toast_overlay_get_child (AdwToastOverlay *self)
@@ -588,8 +581,6 @@ adw_toast_overlay_get_child (AdwToastOverlay *self)
  * @child: (nullable): the child widget
  *
  * Sets the child widget of @self.
- *
- * Since: 1.0
  */
 void
 adw_toast_overlay_set_child (AdwToastOverlay *self,
@@ -627,8 +618,6 @@ adw_toast_overlay_set_child (AdwToastOverlay *self,
  *
  * If called on a toast currently in the queue, the toast will be bumped
  * forward to be shown as soon as possible.
- *
- * Since: 1.0
  */
 void
 adw_toast_overlay_add_toast (AdwToastOverlay *self,
